@@ -31,7 +31,7 @@
 
 #include <config.h>
 
-#include <cogl/cogl-texture-pixmap-x11.h>
+#include <cogl/winsys/cogl-texture-pixmap-x11.h>
 
 #include <clutter/clutter.h>
 
@@ -61,8 +61,8 @@ struct _MetaScreenBackground
 
   float texture_width;
   float texture_height;
-  CoglHandle texture;
-  CoglMaterialWrapMode wrap_mode;
+  CoglTexture *texture;
+  CoglPipelineWrapMode wrap_mode;
   guint have_pixmap : 1;
 };
 
@@ -90,7 +90,7 @@ static GParamSpec *obj_props[PROP_LAST];
 G_DEFINE_TYPE (MetaBackgroundActor, meta_background_actor, CLUTTER_TYPE_ACTOR);
 
 static void set_texture                (MetaScreenBackground *background,
-                                        CoglHandle            texture);
+                                        CoglTexture          *texture);
 static void set_texture_to_stage_color (MetaScreenBackground *background);
 
 static void
@@ -105,7 +105,7 @@ on_notify_stage_color (GObject              *stage,
 static void
 free_screen_background (MetaScreenBackground *background)
 {
-  set_texture (background, COGL_INVALID_HANDLE);
+  set_texture (background, NULL);
 
   if (background->screen != NULL)
     {
@@ -165,9 +165,9 @@ update_wrap_mode (MetaScreenBackground *background)
    * side of the image via bilinear filtering.
    */
   if (width == background->texture_width && height == background->texture_height)
-    background->wrap_mode = COGL_MATERIAL_WRAP_MODE_CLAMP_TO_EDGE;
+    background->wrap_mode = COGL_PIPELINE_WRAP_MODE_CLAMP_TO_EDGE;
   else
-    background->wrap_mode = COGL_MATERIAL_WRAP_MODE_REPEAT;
+    background->wrap_mode = COGL_PIPELINE_WRAP_MODE_REPEAT;
 
   for (l = background->actors; l; l = l->next)
     update_wrap_mode_of_actor (l->data);
@@ -181,12 +181,12 @@ cancel_transitions (MetaBackgroundActor *self)
   clutter_actor_remove_all_transitions (priv->top_actor);
   clutter_actor_set_opacity (priv->top_actor, 255);
   meta_background_set_layer (META_BACKGROUND (priv->bottom_actor), priv->background->texture);
-  
+
   priv->transition_running = FALSE;
 }
 
 static void
-on_trasition_complete (ClutterActor *actor,
+on_transition_complete (ClutterActor *actor,
                        gpointer      user_data)
 {
   MetaBackgroundActor *self = (MetaBackgroundActor *)user_data;
@@ -211,31 +211,51 @@ static void
 set_texture_on_actor (MetaBackgroundActor *self)
 {
   MetaBackgroundActorPrivate *priv = self->priv;
+  MetaBackgroundTransition background_transition;
 
   if (priv->transition_running)
     cancel_transitions (self);
 
-  clutter_actor_set_opacity (CLUTTER_ACTOR (priv->top_actor), 0);
-  meta_background_set_layer (META_BACKGROUND (priv->top_actor), priv->background->texture);
+  background_transition = meta_prefs_get_background_transition();
 
-  priv->transition_running = TRUE;
+  if (background_transition == META_BACKGROUND_TRANSITION_NONE)
+  {
+    // NO TRANSITION
+    clutter_actor_set_opacity (CLUTTER_ACTOR (priv->bottom_actor), 0);
+    meta_background_set_layer (META_BACKGROUND (priv->top_actor), priv->background->texture);
+    on_transition_complete (priv->top_actor, self);
+  }
+  else
+  {
+    if (background_transition == META_BACKGROUND_TRANSITION_FADEIN)
+    {
+      // FADE_IN TRANSITION
+      clutter_actor_set_opacity (CLUTTER_ACTOR (priv->bottom_actor), 0);
+    }
 
-  clutter_actor_save_easing_state (priv->top_actor);
-  clutter_actor_set_easing_duration (priv->top_actor, FADE_DURATION);
-  clutter_actor_set_opacity (priv->top_actor, 255);
-  clutter_actor_restore_easing_state (priv->top_actor);
+    // BLEND TRANSITION
+    clutter_actor_set_opacity (CLUTTER_ACTOR (priv->top_actor), 0);
+    meta_background_set_layer (META_BACKGROUND (priv->top_actor), priv->background->texture);
 
-  g_signal_connect (priv->top_actor,
-                    "transitions-completed",
-                    G_CALLBACK (on_trasition_complete),
-                    self);
+    priv->transition_running = TRUE;
 
-  clutter_actor_queue_redraw (CLUTTER_ACTOR (self));
+    clutter_actor_save_easing_state (priv->top_actor);
+    clutter_actor_set_easing_duration (priv->top_actor, FADE_DURATION);
+    clutter_actor_set_opacity (priv->top_actor, 255);
+    clutter_actor_restore_easing_state (priv->top_actor);
+
+    g_signal_connect (priv->top_actor,
+                      "transitions-completed",
+                      G_CALLBACK (on_transition_complete),
+                      self);
+
+    clutter_actor_queue_redraw (CLUTTER_ACTOR (self));
+  }
 }
 
 static void
 set_texture (MetaScreenBackground *background,
-             CoglHandle            texture)
+             CoglTexture          *texture)
 {
   MetaDisplay *display = meta_screen_get_display (background->screen);
   GSList *l;
@@ -244,15 +264,15 @@ set_texture (MetaScreenBackground *background,
    * the underlying X pixmap is already gone has the tendency to trigger
    * X errors inside DRI. For safety, trap errors */
   meta_error_trap_push (display);
-  if (background->texture != COGL_INVALID_HANDLE)
+  if (background->texture != NULL)
     {
-      cogl_handle_unref (background->texture);
-      background->texture = COGL_INVALID_HANDLE;
+      cogl_object_unref (background->texture);
+      background->texture = NULL;
     }
   meta_error_trap_pop (display);
 
-  if (texture != COGL_INVALID_HANDLE)
-    background->texture = cogl_handle_ref (texture);
+  if (texture != NULL)
+    background->texture = cogl_object_ref (texture);
 
   background->texture_width = cogl_texture_get_width (background->texture);
   background->texture_height = cogl_texture_get_height (background->texture);
@@ -275,7 +295,7 @@ set_texture_to_stage_color (MetaScreenBackground *background)
 {
   ClutterActor *stage = meta_get_stage_for_screen (background->screen);
   ClutterColor color;
-  CoglHandle texture;
+  CoglTexture *texture;
 
   clutter_actor_get_background_color (stage, &color);
 
@@ -286,7 +306,7 @@ set_texture_to_stage_color (MetaScreenBackground *background)
                                            color.blue, 0xff,
                                            COGL_TEXTURE_NO_SLICING);
   set_texture (background, texture);
-  cogl_handle_unref (texture);
+  cogl_object_unref (texture);
 }
 
 static void
@@ -303,6 +323,12 @@ meta_background_actor_dispose (GObject *object)
       priv->background = NULL;
     }
 
+  if (priv->top_actor != NULL)
+    priv->top_actor = NULL;
+
+  if (priv->bottom_actor != NULL)
+    priv->bottom_actor = NULL;
+
   G_OBJECT_CLASS (meta_background_actor_parent_class)->dispose (object);
 }
 
@@ -543,17 +569,16 @@ meta_background_actor_update (MetaScreen *screen)
   if (root_pixmap_id != None)
     {
       CoglHandle texture;
-      CoglContext *ctx = clutter_backend_get_cogl_context (clutter_get_default_backend ());
       GError *error = NULL;
 
       meta_error_trap_push (display);
-      texture = cogl_texture_pixmap_x11_new (ctx, root_pixmap_id, FALSE, &error);
+      texture = cogl_texture_pixmap_x11_new (compositor->context, root_pixmap_id, FALSE, &error);
       meta_error_trap_pop (display);
 
-      if (texture != COGL_INVALID_HANDLE)
+      if (texture != NULL)
         {
           set_texture (background, texture);
-          cogl_handle_unref (texture);
+          cogl_object_unref (texture);
 
           background->have_pixmap = True;
           return;
@@ -589,7 +614,8 @@ meta_background_actor_set_visible_region (MetaBackgroundActor *self,
 
   priv = self->priv;
 
-  meta_background_set_visible_region (META_BACKGROUND (priv->top_actor), visible_region);
+  if (priv->top_actor != NULL)
+    meta_background_set_visible_region (META_BACKGROUND (priv->top_actor), visible_region);
 }
 
 /**
