@@ -72,8 +72,8 @@ struct _MetaShadow
 
   MetaShadowFactory *factory;
   MetaShadowCacheKey key;
-  CoglHandle texture;
-  CoglHandle material;
+  CoglTexture *texture;
+  CoglPipeline *pipeline;
 
   /* The outer order is the distance the shadow extends outside the window
    * shape; the inner border is the unscaled portion inside the window
@@ -115,15 +115,6 @@ struct _MetaShadowFactoryClass
   GObjectClass parent_class;
 };
 
-enum
-{
-  CHANGED,
-
-  LAST_SIGNAL
-};
-
-static guint signals[LAST_SIGNAL] = { 0 };
-
 /* The first element in this array also defines the default parameters
  * for newly created classes */
 static MetaShadowClassInfo default_shadow_classes[] = {
@@ -182,8 +173,8 @@ meta_shadow_unref (MetaShadow *shadow)
         }
 
       meta_window_shape_unref (shadow->key.shape);
-      cogl_handle_unref (shadow->texture);
-      cogl_handle_unref (shadow->material);
+      cogl_object_unref (shadow->texture);
+      cogl_object_unref (shadow->pipeline);
 
       g_slice_free (MetaShadow, shadow);
     }
@@ -207,14 +198,16 @@ meta_shadow_unref (MetaShadow *shadow)
  * size needs to be passed in here.)
  */
 LOCAL_SYMBOL void
-meta_shadow_paint (MetaShadow     *shadow,
-                   int             window_x,
-                   int             window_y,
-                   int             window_width,
-                   int             window_height,
-                   guint8          opacity,
-                   cairo_region_t *clip,
-                   gboolean        clip_strictly)
+meta_shadow_paint (MetaShadow      *shadow,
+                   CoglFramebuffer *framebuffer,
+                   int              window_x,
+                   int              window_y,
+                   int              window_width,
+                   int              window_height,
+                   guint8           opacity,
+                   cairo_region_t  *clip,
+                   gboolean         clip_strictly)
+
 {
   float texture_width = cogl_texture_get_width (shadow->texture);
   float texture_height = cogl_texture_get_height (shadow->texture);
@@ -224,11 +217,7 @@ meta_shadow_paint (MetaShadow     *shadow,
   int dest_x[4];
   int dest_y[4];
   int n_x, n_y;
-
-  cogl_material_set_color4ub (shadow->material,
-                              opacity, opacity, opacity, opacity);
-
-  cogl_set_source (shadow->material);
+  gboolean source_updated = FALSE;
 
   if (shadow->scale_width)
     {
@@ -304,6 +293,17 @@ meta_shadow_paint (MetaShadow     *shadow,
           else
             overlap = CAIRO_REGION_OVERLAP_IN;
 
+          if (overlap == CAIRO_REGION_OVERLAP_OUT)
+            continue;
+
+          if (!source_updated)
+            {
+              cogl_pipeline_set_color4ub (shadow->pipeline,
+                                          opacity, opacity, opacity, opacity);
+//              cogl_set_source (shadow->pipeline); do not believe needed, but still there in mutter
+              source_updated = TRUE;
+            }
+
           /* There's quite a bit of overhead from allocating a new
            * region in order to find an exact intersection and
            * generating more geometry - we make the assumption that
@@ -313,24 +313,30 @@ meta_shadow_paint (MetaShadow     *shadow,
           if (overlap == CAIRO_REGION_OVERLAP_IN ||
               (overlap == CAIRO_REGION_OVERLAP_PART && !clip_strictly))
             {
-              cogl_rectangle_with_texture_coords (dest_x[i], dest_y[j],
-                                                  dest_x[i + 1], dest_y[j + 1],
-                                                  src_x[i], src_y[j],
-                                                  src_x[i + 1], src_y[j + 1]);
+              cogl_framebuffer_draw_textured_rectangle (framebuffer,
+                                                        shadow->pipeline,
+                                                        dest_x[i], dest_y[j],
+                                                        dest_x[i + 1], dest_y[j + 1],
+                                                        src_x[i], src_y[j],
+                                                        src_x[i + 1], src_y[j + 1]);
             }
           else if (overlap == CAIRO_REGION_OVERLAP_PART)
             {
               cairo_region_t *intersection;
               int n_rectangles, k;
+              float *rects;
 
               intersection = cairo_region_create_rectangle (&dest_rect);
               cairo_region_intersect (intersection, clip);
 
               n_rectangles = cairo_region_num_rectangles (intersection);
+              rects = g_alloca (sizeof (float) * 8 * n_rectangles);
+
               for (k = 0; k < n_rectangles; k++)
                 {
                   cairo_rectangle_int_t rect;
                   float src_x1, src_x2, src_y1, src_y2;
+                  int pos;
 
                   cairo_region_get_rectangle (intersection, k, &rect);
 
@@ -347,11 +353,22 @@ meta_shadow_paint (MetaShadow     *shadow,
                   src_y2 = (src_y[j] * (dest_rect.y + dest_rect.height - (rect.y + rect.height)) +
                             src_y[j + 1] * (rect.y + rect.height - dest_rect.y)) / dest_rect.height;
 
-                  cogl_rectangle_with_texture_coords (rect.x, rect.y,
-                                                      rect.x + rect.width, rect.y + rect.height,
-                                                      src_x1, src_y1, src_x2, src_y2);
+                  pos = k*8;
+                  rects[pos] = rect.x;
+                  rects[pos+1] = rect.y;
+                  rects[pos+2] = rect.x + rect.width;
+                  rects[pos+3] = rect.y + rect.height;
+                  rects[pos+4] = src_x1;
+                  rects[pos+5] = src_y1;
+                  rects[pos+6] = src_x2;
+                  rects[pos+7] = src_y2;
                 }
 
+              cogl_framebuffer_draw_textured_rectangles (framebuffer,
+                                                         shadow->pipeline,
+                                                         rects,
+                                                         n_rectangles);
+
               cairo_region_destroy (intersection);
             }
         }
@@ -386,7 +403,7 @@ meta_shadow_get_bounds  (MetaShadow            *shadow,
 static void
 meta_shadow_class_info_free (MetaShadowClassInfo *class_info)
 {
-  g_free ((char *)class_info->name);
+  free ((char *)class_info->name);
   g_slice_free (MetaShadowClassInfo, class_info);
 }
 
@@ -443,14 +460,6 @@ meta_shadow_factory_class_init (MetaShadowFactoryClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   object_class->finalize = meta_shadow_factory_finalize;
-
-  signals[CHANGED] =
-    g_signal_new ("changed",
-                  G_TYPE_FROM_CLASS (object_class),
-                  G_SIGNAL_RUN_LAST,
-                  0,
-                  NULL, NULL, NULL,
-                  G_TYPE_NONE, 0);
 }
 
 LOCAL_SYMBOL MetaShadowFactory *
@@ -577,7 +586,7 @@ blur_rows (cairo_region_t   *convolve_region,
   int n_rectangles;
   guchar *tmp_buffer;
 
-  tmp_buffer = g_malloc (buffer_width);
+  tmp_buffer = malloc (buffer_width);
 
   n_rectangles = cairo_region_num_rectangles (convolve_region);
   for (i = 0; i < n_rectangles; i++)
@@ -613,7 +622,7 @@ blur_rows (cairo_region_t   *convolve_region,
 	}
     }
 
-  g_free (tmp_buffer);
+  free (tmp_buffer);
 }
 
 static void
@@ -679,7 +688,7 @@ flip_buffer (guchar *buffer,
     }
   else
     {
-      guchar *new_buffer = g_malloc (height * width);
+      guchar *new_buffer = malloc (height * width);
       int i0, j0;
 
       for (i0 = 0; i0 < width; i0 += BLOCK_SIZE)
@@ -694,7 +703,7 @@ flip_buffer (guchar *buffer,
 		new_buffer[i * height + j] = buffer[j * width + i];
 	  }
 
-      g_free (buffer);
+      free (buffer);
 
       return new_buffer;
     }
@@ -743,7 +752,7 @@ make_shadow (MetaShadow     *shadow,
   if (buffer_width < buffer_height && buffer_width > (3 * buffer_height) / 4)
     buffer_width = buffer_height;
 
-  buffer = g_malloc0 (buffer_width * buffer_height);
+  buffer = calloc (1, buffer_width * buffer_height);
 
   /* Blurring with multiple box-blur passes is fast, but (especially for
    * large shadow sizes) we can improve efficiency by restricting the blur
@@ -806,9 +815,9 @@ make_shadow (MetaShadow     *shadow,
 
   cairo_region_destroy (row_convolve_region);
   cairo_region_destroy (column_convolve_region);
-  g_free (buffer);
+  free (buffer);
 
-  shadow->material = meta_create_texture_material (shadow->texture);
+  shadow->pipeline = meta_create_texture_pipeline (shadow->texture);
 }
 
 static MetaShadowParams *
@@ -1016,7 +1025,7 @@ meta_shadow_factory_set_params (MetaShadowFactory *factory,
 
   *stored_params = *params;
 
-  g_signal_emit (factory, signals[CHANGED], 0);
+  meta_compositor_on_shadow_factory_changed ();
 }
 
 /**
