@@ -117,12 +117,6 @@ meta_core_get (Display *xdisplay,
       case META_CORE_GET_FRAME_TYPE:
         *((MetaFrameType*)answer) = meta_window_get_frame_type (window);
         break;
-      case META_CORE_GET_MINI_ICON:
-        *((GdkPixbuf**)answer) = window->mini_icon;
-        break;
-      case META_CORE_GET_ICON:
-        *((GdkPixbuf**)answer) = window->icon;
-        break;
       case META_CORE_GET_X:
         meta_window_get_position (window, (int*)answer, NULL);
         break;
@@ -171,6 +165,7 @@ meta_core_queue_frame_resize (Display *xdisplay,
   MetaWindow *window = meta_core_get_window (xdisplay, frame_xwindow);
 
   meta_window_queue (window, META_QUEUE_MOVE_RESIZE);
+  meta_window_frame_size_changed (window);
 }
 
 LOCAL_SYMBOL void
@@ -669,6 +664,8 @@ meta_core_get_menu_accelerator (MetaMenuOp           menu_op,
     case META_MENU_OP_RECOVER:
       /* No keybinding for this one */
       break;
+    default:
+      break;
     }
 
   if (name)
@@ -813,28 +810,3 @@ meta_core_increment_event_serial (Display *xdisplay)
   meta_display_increment_event_serial (display);
 }
 
-LOCAL_SYMBOL void
-meta_invalidate_default_icons (void)
-{
-  MetaDisplay *display = meta_get_display ();
-  GSList *windows;
-  GSList *l;
-
-  if (display == NULL)
-    return; /* We can validly be called before the display is opened. */
-
-  windows = meta_display_list_windows (display, META_LIST_DEFAULT);
-  for (l = windows; l != NULL; l = l->next)
-    {
-      MetaWindow *window = (MetaWindow*)l->data;
-
-      if (window->icon_cache.origin == USING_FALLBACK_ICON)
-        {
-          meta_icon_cache_free (&(window->icon_cache));
-          meta_window_update_icon_now (window);
-        }
-    }
-
-  g_slist_free (windows);
-}
-
