@@ -2,7 +2,7 @@
 
 /* Muffin preferences */
 
-/* 
+/*
  * Copyright (C) 2001 Havoc Pennington, Copyright (C) 2002 Red Hat Inc.
  * Copyright (C) 2006 Elijah Newren
  * Copyright (C) 2008 Thomas Thurman
@@ -17,7 +17,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Suite 500, Boston, MA
@@ -37,6 +37,7 @@
 #include "meta-plugin-manager.h"
 #include <glib.h>
 #include <gio/gio.h>
+#include <gtk/gtk.h>
 #include <string.h>
 #include <stdlib.h>
 #include "keybindings-private.h"
@@ -87,6 +88,7 @@ static CDesktopFocusMode focus_mode = C_DESKTOP_FOCUS_MODE_CLICK;
 static CDesktopFocusNewWindows focus_new_windows = C_DESKTOP_FOCUS_NEW_WINDOWS_SMART;
 static gboolean raise_on_click = TRUE;
 static gboolean attach_modal_dialogs = FALSE;
+static gboolean ignore_hide_titlebar_when_maximized = FALSE;
 static char* current_theme = NULL;
 static int num_workspaces = 4;
 static gboolean workspace_cycle = FALSE;
@@ -96,6 +98,10 @@ static CDesktopTitlebarAction action_right_click_titlebar = C_DESKTOP_TITLEBAR_A
 static CDesktopTitlebarScrollAction action_scroll_titlebar = C_DESKTOP_TITLEBAR_SCROLL_ACTION_NONE;
 static gboolean dynamic_workspaces = FALSE;
 static gboolean unredirect_fullscreen_windows = FALSE;
+static gboolean desktop_effects = TRUE;
+static MetaSyncMethod sync_method = META_SYNC_PRESENTATION_TIME;
+static gboolean threaded_swap = TRUE;
+static gboolean send_frame_timings = TRUE;
 static gboolean application_based = FALSE;
 static gboolean disable_workarounds = FALSE;
 static gboolean auto_raise = FALSE;
@@ -290,6 +296,13 @@ static MetaEnumPreference preferences_enum[] =
       },
       &background_transition,
     },
+    {
+      { "sync-method",
+        SCHEMA_MUFFIN,
+        META_PREF_SYNC_METHOD,
+      },
+      &sync_method,
+    },
     { { NULL, 0, 0 }, NULL },
   };
 
@@ -302,6 +315,13 @@ static MetaBoolPreference preferences_bool[] =
       },
       &attach_modal_dialogs,
     },
+    {
+      { "ignore-hide-titlebar-when-maximized",
+        SCHEMA_MUFFIN,
+        META_PREF_IGNORE_HIDE_TITLEBAR_WHEN_MAXIMIZED,
+      },
+      &ignore_hide_titlebar_when_maximized,
+    },
     {
       { "raise-on-click",
         SCHEMA_GENERAL,
@@ -337,6 +357,27 @@ static MetaBoolPreference preferences_bool[] =
       },
       &unredirect_fullscreen_windows,
     },
+    {
+      { "desktop-effects",
+        SCHEMA_MUFFIN,
+        META_PREF_DESKTOP_EFFECTS,
+      },
+      &desktop_effects,
+    },
+    {
+      { "threaded-swap",
+        SCHEMA_MUFFIN,
+        META_PREF_THREADED_SWAP,
+      },
+      &threaded_swap,
+    },
+    {
+      { "send-frame-timings",
+        SCHEMA_MUFFIN,
+        META_PREF_SEND_FRAME_TIMINGS,
+      },
+      &send_frame_timings,
+    },
     {
       { "application-based",
         SCHEMA_GENERAL,
@@ -606,8 +647,7 @@ handle_preference_init_string (void)
           if (!cursor->target)
             meta_bug ("%s must have handler or target\n", cursor->base.key);
 
-          if (*(cursor->target))
-            g_free (*(cursor->target));
+          free (*(cursor->target));
 
           value = g_settings_get_string (SETTINGS (cursor->base.schema),
                                          cursor->base.key);
@@ -624,7 +664,7 @@ handle_preference_init_int (void)
 {
   MetaIntPreference *cursor = preferences_int;
 
-  
+
   while (cursor->base.key != NULL)
     {
       if (cursor->target)
@@ -680,7 +720,7 @@ handle_preference_update_bool (GSettings *settings,
    * store the current value away.
    */
   old_value = *((gboolean *) cursor->target);
-  
+
   /* Now look it up... */
   *((gboolean *) cursor->target) =
     g_settings_get_boolean (SETTINGS (cursor->base.schema), key);
@@ -727,8 +767,7 @@ handle_preference_update_string (GSettings *settings,
 
       inform_listeners = (g_strcmp0 (value, *(cursor->target)) != 0);
 
-      if (*(cursor->target))
-        g_free(*(cursor->target));
+      free(*(cursor->target));
 
       *(cursor->target) = value;
     }
@@ -801,12 +840,12 @@ meta_prefs_remove_listener (MetaPrefsChangedFunc func,
       if (l->func == func &&
           l->data == data)
         {
-          g_free (l);
+          free (l);
           listeners = g_list_delete_link (listeners, tmp);
 
           return;
         }
-      
+
       tmp = tmp->next;
     }
 
@@ -821,9 +860,9 @@ emit_changed (MetaPreference pref)
 
   meta_topic (META_DEBUG_PREFS, "Notifying listeners that pref %s changed\n",
               meta_preference_to_string (pref));
-  
+
   copy = g_list_copy (listeners);
-  
+
   tmp = copy;
 
   while (tmp != NULL)
@@ -845,24 +884,24 @@ changed_idle_handler (gpointer data)
   GList *copy;
 
   changed_idle = 0;
-  
+
   copy = g_list_copy (changes); /* reentrancy paranoia */
 
   g_list_free (changes);
   changes = NULL;
-  
+
   tmp = copy;
   while (tmp != NULL)
     {
       MetaPreference pref = GPOINTER_TO_INT (tmp->data);
 
       emit_changed (pref);
-      
+
       tmp = tmp->next;
     }
 
   g_list_free (copy);
-  
+
   return FALSE;
 }
 
@@ -870,30 +909,47 @@ static void
 queue_changed (MetaPreference pref)
 {
   meta_topic (META_DEBUG_PREFS, "Queueing change of pref %s\n",
-              meta_preference_to_string (pref));  
+              meta_preference_to_string (pref));
 
   if (g_list_find (changes, GINT_TO_POINTER (pref)) == NULL)
     changes = g_list_prepend (changes, GINT_TO_POINTER (pref));
+#ifdef WITH_VERBOSE_MODE
   else
     meta_topic (META_DEBUG_PREFS, "Change of pref %s was already pending\n",
                 meta_preference_to_string (pref));
-
+#endif
   if (changed_idle == 0)
     changed_idle = g_idle_add_full (META_PRIORITY_PREFS_NOTIFY,
                                     changed_idle_handler, NULL, NULL);
 }
 
 static void
-update_ui_scale (GdkScreen *screen, gpointer data)
+store_initial_ui_scale (void)
 {
   GValue value = G_VALUE_INIT;
 
   g_value_init (&value, G_TYPE_INT);
 
-  gdk_screen_get_setting (screen, "gdk-window-scaling-factor", &value);
+  gdk_screen_get_setting (gdk_screen_get_default (), "gdk-window-scaling-factor", &value);
   ui_scale = MAX (g_value_get_int (&value), 1); // Never let it be 0;
 }
 
+static void
+set_ui_scale (int new_scale)
+{
+  if (new_scale == ui_scale)
+    {
+      return;
+    }
+
+  ui_scale = new_scale;
+
+  meta_topic (META_DEBUG_PREFS, "UI Scale changed (to %dx), triggering frames and cursor size updates.\n",
+              ui_scale);
+
+  queue_changed (META_PREF_UI_SCALE);
+}
+
 
 /****************************************************************************/
 /* Initialisation.                                                          */
@@ -906,7 +962,7 @@ meta_prefs_init (void)
   GSList *tmp;
 
   settings_schemas = g_hash_table_new_full (g_str_hash, g_str_equal,
-                                            g_free, g_object_unref);
+                                            free, g_object_unref);
 
   settings = g_settings_new (SCHEMA_GENERAL);
   g_signal_connect (settings, "changed", G_CALLBACK (settings_changed), NULL);
@@ -944,14 +1000,7 @@ meta_prefs_init (void)
   handle_preference_init_string ();
   handle_preference_init_int ();
 
-  GdkDisplay *display = gdk_display_get_default();
-
-  g_signal_connect (gdk_display_get_default_screen (display), "monitors-changed",
-                    G_CALLBACK (update_ui_scale), NULL);
-  g_signal_connect (gdk_display_get_default_screen (display), "size-changed",
-                    G_CALLBACK (update_ui_scale), NULL);
-
-  update_ui_scale (gdk_display_get_default_screen (display), NULL);
+  store_initial_ui_scale ();
 
   init_bindings ();
   init_workspace_names ();
@@ -1025,7 +1074,7 @@ do_override (char *key,
   detailed_signal = g_strdup_printf ("changed::%s", key);
   handler_id = g_signal_connect (settings, detailed_signal,
                                  G_CALLBACK (settings_changed), NULL);
-  g_free (detailed_signal);
+  free (detailed_signal);
 
   g_object_set_data (G_OBJECT (settings), key, GUINT_TO_POINTER (handler_id));
 
@@ -1071,7 +1120,7 @@ meta_prefs_override_preference_schema (const char *key, const char *schema)
 
   if (overridden)
     {
-      g_free (overridden->new_schema);
+      free (overridden->new_schema);
       overridden->new_schema = g_strdup (schema);
     }
   else
@@ -1103,7 +1152,7 @@ settings_changed (GSettings *settings,
   MetaEnumPreference *cursor;
   gboolean found_enum;
   gchar *schema;
-  
+
   g_object_get(settings, "schema", &schema, NULL);
 
   /* String array, handled separately */
@@ -1113,7 +1162,7 @@ settings_changed (GSettings *settings,
         queue_changed (META_PREF_WORKSPACE_NAMES);
       return;
     }
-  
+
   if (strcmp (key, KEY_MIN_WINDOW_OPACITY) == 0)
     {
       update_min_win_opacity ();
@@ -1182,7 +1231,7 @@ static void
 maybe_give_disable_workarounds_warning (void)
 {
   static gboolean first_disable = TRUE;
-    
+
   if (first_disable && disable_workarounds)
     {
       first_disable = FALSE;
@@ -1228,6 +1277,12 @@ meta_prefs_get_attach_modal_dialogs (void)
   return attach_modal_dialogs;
 }
 
+gboolean
+meta_prefs_get_ignore_hide_titlebar_when_maximized (void)
+{
+  return ignore_hide_titlebar_when_maximized;
+}
+
 gboolean
 meta_prefs_get_raise_on_click (void)
 {
@@ -1314,9 +1369,7 @@ theme_name_handler (GVariant *value,
 
   if (g_strcmp0 (current_theme, string_value) != 0)
     {
-      if (current_theme)
-        g_free (current_theme);
-
+      free (current_theme);
       current_theme = g_strdup (string_value);
       queue_changed (META_PREF_THEME);
     }
@@ -1339,7 +1392,7 @@ mouse_button_mods_handler (GVariant *value,
     {
       meta_topic (META_DEBUG_KEYBINDINGS,
                   "Failed to parse new GSettings value\n");
-          
+
       meta_warning (_("\"%s\" found in configuration database is "
                       "not a valid value for mouse button modifier\n"),
                     string_value);
@@ -1437,7 +1490,7 @@ snap_modifier_handler (GVariant *value,
 static gboolean
 button_layout_equal (const MetaButtonLayout *a,
                      const MetaButtonLayout *b)
-{  
+{
   int i;
 
   i = 0;
@@ -1478,7 +1531,7 @@ button_function_from_string (const char *str)
     return META_BUTTON_FUNCTION_ABOVE;
   else if (strcmp (str, "stick") == 0)
     return META_BUTTON_FUNCTION_STICK;
-  else 
+  else
     /* don't know; give up */
     return META_BUTTON_FUNCTION_LAST;
 }
@@ -1571,11 +1624,13 @@ button_layout_handler (GVariant *value,
                   if (f != META_BUTTON_FUNCTION_LAST)
                       new_layout.left_buttons[i++] = f;
                 }
+#ifdef WITH_VERBOSE_MODE
               else
                 {
                   meta_topic (META_DEBUG_PREFS, "Ignoring unknown or already-used button name \"%s\"\n",
                               buttons[b]);
                 }
+#endif
             }
 
           ++b;
@@ -1603,7 +1658,7 @@ button_layout_handler (GVariant *value,
           new_layout.right_buttons_has_spacer[i] = FALSE;
           ++i;
         }
-      
+
       buttons = g_strsplit (sides[1], ",", -1);
       i = 0;
       b = 0;
@@ -1633,13 +1688,15 @@ button_layout_handler (GVariant *value,
                       new_layout.right_buttons[i++] = f;
 
                 }
+#ifdef WITH_VERBOSE_MODE
               else
                 {
                   meta_topic (META_DEBUG_PREFS, "Ignoring unknown or already-used button name \"%s\"\n",
                               buttons[b]);
                 }
+#endif
             }
-          
+
           ++b;
         }
 
@@ -1653,13 +1710,13 @@ button_layout_handler (GVariant *value,
     }
 
   g_strfreev (sides);
-  
+
   /* Invert the button layout for RTL languages */
   if (meta_ui_get_direction() == META_UI_DIRECTION_RTL)
   {
     MetaButtonLayout rtl_layout;
     int j;
-    
+
     for (i = 0; new_layout.left_buttons[i] != META_BUTTON_FUNCTION_LAST; i++);
     for (j = 0; j < i; j++)
       {
@@ -1671,7 +1728,7 @@ button_layout_handler (GVariant *value,
       }
     rtl_layout.right_buttons[j] = META_BUTTON_FUNCTION_LAST;
     rtl_layout.right_buttons_has_spacer[j] = FALSE;
-      
+
     for (i = 0; new_layout.right_buttons[i] != META_BUTTON_FUNCTION_LAST; i++);
     for (j = 0; j < i; j++)
       {
@@ -1729,11 +1786,35 @@ meta_prefs_get_unredirect_fullscreen_windows (void)
   return unredirect_fullscreen_windows;
 }
 
+gboolean
+meta_prefs_get_desktop_effects (void)
+{
+  return desktop_effects;
+}
+
+MetaSyncMethod
+meta_prefs_get_sync_method (void)
+{
+  return sync_method;
+}
+
+gboolean
+meta_prefs_get_threaded_swap (void)
+{
+  return threaded_swap;
+}
+
+gboolean
+meta_prefs_get_send_frame_timings (void)
+{
+  return send_frame_timings;
+}
+
 gboolean
 meta_prefs_get_application_based (void)
 {
   return FALSE; /* For now, we never want this to do anything */
-  
+
   return application_based;
 }
 
@@ -1770,7 +1851,7 @@ meta_preference_to_string (MetaPreference pref)
 
     case META_PREF_RAISE_ON_CLICK:
       return "RAISE_ON_CLICK";
-      
+
     case META_PREF_THEME:
       return "THEME";
 
@@ -1803,7 +1884,7 @@ meta_preference_to_string (MetaPreference pref)
 
     case META_PREF_AUTO_RAISE:
       return "AUTO_RAISE";
-      
+
     case META_PREF_AUTO_RAISE_DELAY:
       return "AUTO_RAISE_DELAY";
 
@@ -1864,6 +1945,15 @@ meta_preference_to_string (MetaPreference pref)
     case META_PREF_UNREDIRECT_FULLSCREEN_WINDOWS:
       return "UNREDIRECT_FULLSCREEN_WINDOWS";
 
+    case META_PREF_SYNC_METHOD:
+      return "SYNC_METHOD";
+
+    case META_PREF_THREADED_SWAP:
+      return "THREADED_SWAP";
+
+    case META_PREF_SEND_FRAME_TIMINGS:
+      return "SEND_FRAME_TIMINGS";
+
     case META_PREF_SNAP_MODIFIER:
       return "SNAP_MODIFIER";
 
@@ -1910,16 +2000,16 @@ meta_key_pref_free (MetaKeyPref *pref)
 {
   update_binding (pref, NULL);
 
-  g_free (pref->name);
-  g_free (pref->schema);
+  free (pref->name);
+  free (pref->schema);
 
-  g_free (pref);
+  free (pref);
 }
 
 static void
 init_bindings (void)
 {
-  key_bindings = g_hash_table_new_full (g_str_hash, g_str_equal, g_free,
+  key_bindings = g_hash_table_new_full (g_str_hash, g_str_equal, free,
                                         (GDestroyNotify)meta_key_pref_free);
 }
 
@@ -1946,10 +2036,10 @@ update_binding (MetaKeyPref *binding,
   /* Okay, so, we're about to provide a new list of key combos for this
    * action. Delete any pre-existing list.
    */
-  g_slist_foreach (binding->bindings, (GFunc) g_free, NULL);
+  g_slist_foreach (binding->bindings, (GFunc) free, NULL);
   g_slist_free (binding->bindings);
   binding->bindings = NULL;
-  
+
   for (i = 0; strokes && strokes[i]; i++)
     {
       keysym = 0;
@@ -1985,7 +2075,7 @@ update_binding (MetaKeyPref *binding,
           continue;
         }
 
-      combo = g_malloc0 (sizeof (MetaKeyCombo));
+      combo = calloc (1, sizeof (MetaKeyCombo));
       combo->keysym = keysym;
       combo->keycode = keycode;
       combo->modifiers = mods;
@@ -2068,7 +2158,7 @@ meta_prefs_get_workspace_name (int i)
     {
       char *generated_name = g_strdup_printf (_("Workspace %d"), i + 1);
       name = g_intern_string (generated_name);
-      g_free (generated_name);
+      free (generated_name);
     }
   else
     name = workspace_names[i];
@@ -2085,7 +2175,7 @@ meta_prefs_change_workspace_name (int         num,
 {
   GVariantBuilder builder;
   int n_workspace_names, i;
-  
+
   g_return_if_fail (num >= 0);
 
   meta_topic (META_DEBUG_PREFS,
@@ -2097,12 +2187,14 @@ meta_prefs_change_workspace_name (int         num,
    * to avoid saving it literally. */
   if (g_strcmp0 (name, meta_prefs_get_workspace_name (num)) == 0)
     {
+#ifdef WITH_VERBOSE_MODE
       if (!name || !*name)
         meta_topic (META_DEBUG_PREFS,
                     "Workspace %d already uses default name\n", num);
       else
         meta_topic (META_DEBUG_PREFS,
                     "Workspace %d already has name %s\n", num, name);
+#endif
       return;
     }
 
@@ -2186,7 +2278,7 @@ meta_prefs_add_keybinding (const char           *name,
       char *changed_signal = g_strdup_printf ("changed::%s", name);
       id = g_signal_connect (settings, changed_signal,
                              G_CALLBACK (bindings_changed), NULL);
-      g_free (changed_signal);
+      free (changed_signal);
 
       g_object_set_data (G_OBJECT (settings), name, GUINT_TO_POINTER (id));
 
@@ -2279,7 +2371,7 @@ meta_prefs_remove_custom_keybinding (const char *name)
 
 /**
  * meta_prefs_get_keybindings:
- * 
+ *
  * Returns: (element-type MetaKeyPref) (transfer container):
  */
 GList *
@@ -2483,3 +2575,9 @@ meta_prefs_get_ui_scale (void)
 {
   return ui_scale;
 }
+
+void
+meta_prefs_set_ui_scale (int new_scale)
+{
+  set_ui_scale (new_scale);
+}
\ No newline at end of file
