@@ -56,8 +56,7 @@ typedef enum {
 
 typedef enum {
   META_QUEUE_CALC_SHOWING = 1 << 0,
-  META_QUEUE_MOVE_RESIZE  = 1 << 1,
-  META_QUEUE_UPDATE_ICON  = 1 << 2,
+  META_QUEUE_MOVE_RESIZE  = 1 << 1
 } MetaQueueType;
 
 /* edge zones for tiling/snapping identification
@@ -90,7 +89,7 @@ enum {
     ZONE_NONE
 };
 
-#define NUMBER_OF_QUEUES 3
+#define NUMBER_OF_QUEUES 2
 
 #define HUD_WIDTH 24
 #define CSD_TITLEBAR_HEIGHT 48
@@ -134,8 +133,9 @@ struct _MetaWindow
 /* /XappGtkWindow */
 
   GdkPixbuf *icon;
-  GdkPixbuf *mini_icon;
   MetaIconCache icon_cache;
+  int icon_size;
+
   Pixmap wm_hints_pixmap;
   Pixmap wm_hints_mask;
   
@@ -796,8 +796,6 @@ void meta_window_stack_just_above (MetaWindow *window,
 void meta_window_set_user_time (MetaWindow *window,
                                 guint32     timestamp);
 
-void meta_window_update_icon_now (MetaWindow *window);
-
 void meta_window_update_role (MetaWindow *window);
 void meta_window_update_net_wm_type (MetaWindow *window);
 void meta_window_update_for_monitors_changed (MetaWindow *window);
@@ -844,4 +842,5 @@ void meta_window_unextend_by_frame (MetaWindow              *window,
 void meta_window_get_client_area_rect (const MetaWindow      *window,
                                        cairo_rectangle_int_t *rect);
 
+void meta_window_icon_changed (MetaWindow *window);
 #endif
