@@ -2,11 +2,11 @@
 
 /* Muffin window menu */
 
-/* 
+/*
  * Copyright (C) 2001 Havoc Pennington
  * Copyright (C) 2004 Rob Adams
  * Copyright (C) 2005 Elijah Newren
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
@@ -16,7 +16,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Suite 500, Boston, MA
@@ -113,18 +113,18 @@ popup_position_func (GtkMenu   *menu,
                      gboolean  *push_in,
                      gpointer  user_data)
 {
-  GtkRequisition req;      
+  GtkRequisition req;
   GdkPoint *pos;
 
   pos = user_data;
-  
+
   gtk_widget_get_preferred_size (GTK_WIDGET (menu), &req, NULL);
 
   *x = pos->x;
   *y = pos->y;
-  
+
   if (meta_ui_get_direction() == META_UI_DIRECTION_RTL)
-    *x = MAX (0, *x - req.width); 
+    *x = MAX (0, *x - req.width);
 
   /* Ensure onscreen */
   *x = CLAMP (*x, 0, MAX (0, gdk_screen_width () - req.width));
@@ -136,7 +136,7 @@ menu_closed (GtkMenu *widget,
              gpointer data)
 {
   MetaWindowMenu *menu;
-  
+
   menu = data;
 
   meta_frames_notify_menu_hide (menu->frames);
@@ -146,7 +146,7 @@ menu_closed (GtkMenu *widget,
                   gtk_get_current_event_time (),
                   0, 0,
                   menu->data);
-  
+
   /* menu may now be freed */
 }
 
@@ -154,9 +154,9 @@ static void
 activate_cb (GtkWidget *menuitem, gpointer data)
 {
   MenuData *md;
-  
+
   g_return_if_fail (GTK_IS_WIDGET (menuitem));
-  
+
   md = data;
 
   meta_frames_notify_menu_hide (md->menu->frames);
@@ -177,7 +177,7 @@ activate_cb (GtkWidget *menuitem, gpointer data)
  * accelerators. At the moment this means adding a _ if the name is of
  * the form "Workspace n" where n is less than 10, and escaping any
  * other '_'s so they do not create inadvertant accelerators.
- * 
+ *
  * The calling code owns the string, and is reponsible to free the
  * memory after use.
  *
@@ -196,7 +196,7 @@ get_workspace_name_with_accel (Display *display,
   name = meta_core_get_workspace_name_with_index (display, xroot, index);
 
   g_assert (name != NULL);
-  
+
   /*
    * If the name is of the form "Workspace x" where x is an unsigned
    * integer, insert a '_' before the number if it is less than 10 and
@@ -207,7 +207,7 @@ get_workspace_name_with_accel (Display *display,
       *(name + charcount)=='\0')
     {
       char *new_name;
-      
+
       /*
        * Above name is a pointer into the Workspace struct. Here we make
        * a copy copy so we can have our wicked way with it.
@@ -235,7 +235,7 @@ get_workspace_name_with_accel (Display *display,
        * Assume the worst case, that every character is a _.  We also
        * provide memory for " (_#)"
        */
-      new_name = g_malloc0 (strlen (name) * 2 + 6 + 1);
+      new_name = calloc (1, strlen (name) * 2 + 6 + 1);
 
       /*
        * Now iterate down the strings, adding '_' to escape as we go
@@ -279,20 +279,20 @@ menu_item_new (MenuItem *menuitem, int workspace_id)
   else if (menuitem->type == MENU_ITEM_IMAGE)
     {
       GtkWidget *image;
-      
+
       image = gtk_image_new_from_stock (menuitem->stock_id, GTK_ICON_SIZE_MENU);
       mi = gtk_image_menu_item_new ();
-     
+
       gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), image);
       gtk_widget_show (image);
     }
   else if (menuitem->type == MENU_ITEM_CHECKBOX)
     {
       mi = gtk_check_menu_item_new ();
-      
+
       gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi),
                                       menuitem->checked);
-    }    
+    }
   else if (menuitem->type == MENU_ITEM_RADIOBUTTON)
     {
       mi = gtk_check_menu_item_new ();
@@ -318,7 +318,7 @@ menu_item_new (MenuItem *menuitem, int workspace_id)
 
   meta_accel_label_set_accelerator (META_ACCEL_LABEL (accel_label),
                                     key, mods);
-  
+
   return mi;
 }
 
@@ -338,15 +338,15 @@ meta_window_menu_new   (MetaFrames         *frames,
   /* FIXME: Modifications to 'ops' should happen in meta_window_show_menu */
   if (n_workspaces < 2)
     ops &= ~(META_MENU_OP_STICK | META_MENU_OP_UNSTICK | META_MENU_OP_WORKSPACES);
-  
+
   menu = g_new (MetaWindowMenu, 1);
   menu->frames = frames;
   menu->client_xwindow = client_xwindow;
   menu->func = func;
   menu->data = data;
   menu->ops = ops;
-  menu->insensitive = insensitive;  
-  
+  menu->insensitive = insensitive;
+
   menu->menu = gtk_menu_new ();
 
   gtk_menu_set_screen (GTK_MENU (menu->menu),
@@ -375,6 +375,25 @@ meta_window_menu_new   (MetaFrames         *frames,
               gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (mi),
                                               active_workspace != 0xFFFFFFFF);
               break;
+            case META_MENU_OP_NONE:
+            case META_MENU_OP_DELETE:
+            case META_MENU_OP_MINIMIZE:
+            case META_MENU_OP_UNMAXIMIZE:
+            case META_MENU_OP_MAXIMIZE:
+            case META_MENU_OP_UNSHADE:
+            case META_MENU_OP_SHADE:
+            case META_MENU_OP_WORKSPACES:
+            case META_MENU_OP_MOVE:
+            case META_MENU_OP_RESIZE:
+            case META_MENU_OP_ABOVE:
+            case META_MENU_OP_UNABOVE:
+            case META_MENU_OP_MOVE_LEFT:
+            case META_MENU_OP_MOVE_RIGHT:
+            case META_MENU_OP_MOVE_UP:
+            case META_MENU_OP_MOVE_DOWN:
+            case META_MENU_OP_RECOVER:
+            case META_MENU_OP_MOVE_NEW:
+              break;
             default:
               break;
             }
@@ -414,15 +433,15 @@ meta_window_menu_new   (MetaFrames         *frames,
                   for (j = 0; j < n_workspaces; j++)
                     {
                       char *label;
-                      MenuData *md;
-                      unsigned int key;
-                      MetaVirtualModifier mods;
+                      MenuData *md1;
+                      unsigned int key1;
+                      MetaVirtualModifier mods1;
                       MenuItem moveitem;
                       GtkWidget *submi;
 
                       meta_core_get_menu_accelerator (META_MENU_OP_WORKSPACES,
                           j + 1,
-                          &key, &mods);
+                          &key1, &mods1);
 
                       label = get_workspace_name_with_accel (display, xroot, j);
 
@@ -431,15 +450,15 @@ meta_window_menu_new   (MetaFrames         *frames,
                       moveitem.label = label;
                       submi = menu_item_new (&moveitem, j + 1);
 
-                      g_free (label);
+                      free (label);
 
                       if ((active_workspace == (unsigned)j) && (ops & META_MENU_OP_UNSTICK))
                         gtk_widget_set_sensitive (submi, FALSE);
 
-                      md = g_new (MenuData, 1);
+                      md1 = g_new (MenuData, 1);
 
-                      md->menu = menu;
-                      md->op = META_MENU_OP_WORKSPACES;
+                      md1->menu = menu;
+                      md1->op = META_MENU_OP_WORKSPACES;
 
                       g_object_set_data (G_OBJECT (submi),
                           "workspace",
@@ -448,8 +467,8 @@ meta_window_menu_new   (MetaFrames         *frames,
                       g_signal_connect_data (G_OBJECT (submi),
                           "activate",
                           G_CALLBACK (activate_cb),
-                          md,
-                          (GClosureNotify) g_free, 0);
+                          md1,
+                          (GClosureNotify) free, 0);
 
                       gtk_menu_shell_append (GTK_MENU_SHELL (submenu), submi);
 
@@ -466,31 +485,31 @@ meta_window_menu_new   (MetaFrames         *frames,
 
               if (insensitive & menuitem.op)
                 gtk_widget_set_sensitive (mi, FALSE);
-              
+
               md = g_new (MenuData, 1);
-              
+
               md->menu = menu;
               md->op = menuitem.op;
-              
+
               g_signal_connect_data (G_OBJECT (mi),
                                      "activate",
                                      G_CALLBACK (activate_cb),
                                      md,
-                                     (GClosureNotify) g_free, 0);
+                                     (GClosureNotify) free, 0);
             }
 
           if (mi)
             {
               gtk_menu_shell_append (GTK_MENU_SHELL (menu->menu), mi);
-          
+
               gtk_widget_show (mi);
             }
         }
     }
 
- 
+
   g_signal_connect (menu->menu, "selection_done",
-                    G_CALLBACK (menu_closed), menu);  
+                    G_CALLBACK (menu_closed), menu);
 
   return menu;
 }
@@ -503,17 +522,17 @@ meta_window_menu_popup (MetaWindowMenu     *menu,
                         guint32             timestamp)
 {
   GdkPoint *pt;
-  
+
   pt = g_new (GdkPoint, 1);
 
   g_object_set_data_full (G_OBJECT (menu->menu),
                           "destroy-point",
                           pt,
-                          g_free);
+                          free);
 
   pt->x = root_x;
   pt->y = root_y;
-  
+
   gtk_menu_popup (GTK_MENU (menu->menu),
                   NULL, NULL,
                   popup_position_func, pt,
@@ -528,5 +547,5 @@ LOCAL_SYMBOL void
 meta_window_menu_free (MetaWindowMenu *menu)
 {
   gtk_widget_destroy (menu->menu);
-  g_free (menu);
+  free (menu);
 }
