@@ -26,6 +26,7 @@
 
 /* Don't include gtk.h or gdk.h here */
 #include <meta/common.h>
+#include <meta/display.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <cairo.h>
@@ -53,7 +54,7 @@ void meta_ui_remove_event_func (Display       *xdisplay,
                                 MetaEventFunc  func,
                                 gpointer       data);
 
-MetaUI* meta_ui_new (Display *xdisplay,
+MetaUI* meta_ui_new (MetaDisplay *display,
                      Screen  *screen);
 void    meta_ui_free (MetaUI *ui);
 
@@ -136,9 +137,6 @@ GdkPixbuf* meta_gdk_pixbuf_get_from_pixmap (Pixmap       xpixmap,
                                             int          width,
                                             int          height);
 
-GdkPixbuf* meta_ui_get_default_window_icon (MetaUI *ui);
-GdkPixbuf* meta_ui_get_default_mini_icon (MetaUI *ui);
-
 gboolean  meta_ui_window_should_not_cause_focus (Display *xdisplay,
                                                  Window   xwindow);
 
